###############################################################################
## Copyright  1999 Klaus Alexander Seistrup @ Magnetic Ink, Copenhagen, DK
##
##  Author : 1999 Klaus Alexander Seistrup
## Created : Wednesday, 1st December 1999
## Version : 0.1
##
## @(#) $Id: atexit.py,v 1.3 1999/12/02 17:15:50 kas Exp $
##
## Freshmeat appindex record no. 944170539.
##
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by the Free
## Software Foundation; either version 2 of the License, or (at your option)
## any later version.
##
## This program is distributed in the hope that it will be useful, but with-
## out any warranty; without even the implied warranty of merchantability or
## fitness for a particular purpose.  See the GNU General Public License for
## more details.
##
## You should have received a copy of the GNU General Public License along
## with this program; if not, please write to the Free Software Foundation,
## Inc., 59 Temple Place, Suite 330, Boston MA 02111-1307, USA.
###############################################################################
"""
NAME
	atexit  -  register a function to be called at normal pro
	gram termination.

SYNOPSIS
	import atexit

	atexit.atexit(function)

DESCRIPTION
	The atexit() function registers the given function  to  be
	called  at normal program termination.  Functions so  reg
	istered are called in the reverse order of their registra
	tion; no arguments are passed.

RETURN VALUE
	None
"""
###############################################################################

import sys	# This is where exitfunc() lives

# Save exitfunc() in case it has already been assigned
try:
	__ExitFuncs__ = [sys.exitfunc]
except AttributeError:
	__ExitFuncs__ = []
# end try

# This is the function that actually gets called at exit
def __atexit__ ():
	global __ExitFuncs__
	__ExitFuncs__.reverse ()
	for func in __ExitFuncs__:
		if callable (func):
			try:
				func ()
			except:
				pass
			# end try
		# end if
	# end for
# end def __atexit__

# The public interface: atexit()
def atexit (func):
	"""atexit - register a function to be called at normal program termination"""
	global __ExitFuncs__
	if callable (func):
		try:
			oldfunc = sys.exitfunc
		except:
			oldfunc = __atexit__
		# end try
		if oldfunc != __atexit__:
			if oldfunc not in __ExitFuncs__:
				__ExitFuncs__.append (oldfunc)
			# end if
		# end if
		if func not in __ExitFuncs__:
			__ExitFuncs__.append (func)
		# end if
	else:
		raise TypeError, "not a function"
	# end if
	sys.exitfunc = __atexit__
# end def atexit

__version__	= "@(#) $Id: atexit.py,v 1.3 1999/12/02 17:15:50 kas Exp $\0"

#
def version ():
	"""version - display version information"""
	from string import split
	rcs = split (__version__)
	print "atexit 0.%s (%s)" % tuple (rcs[3:5])
# end def version

#
def help ():
	"""help - print __doc__ associated with module"""
	print __doc__
# end def help

#
## Soli Deo Gloria ############################################################
